@@ -1,6 +1,7 @@
 // cygnal.cpp:  GNU streaming Flash media server, for Gnash.
 // 
-// Copyright (C) 2007, 2008, 2009, 2010, 2011 Free Software Foundation, Inc.
+//   Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc.
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -261,7 +262,7 @@ Cygnal::loadPeersFile(const std::string &filespec)
     in.open(filespec.c_str());
     
     if (!in) {
-	log_error(": couldn't open file: ", filespec);
+	log_error(_(": couldn't open file: "), filespec);
 	return false;
     }
 
@@ -338,7 +339,7 @@ Cygnal::probePeers(peer_t &peer)
 	
 	gnash::URL url(uri.str());
 	if (!(peer.fd = net.connectToServer(uri.str()))) {
-	    log_network("Couldn't connect to %s", uri.str());
+	    log_network(_("Couldn't connect to %s"), uri.str());
 	    peer.connected = false;
 	} else {
 	    peer.connected = true;
@@ -354,11 +355,11 @@ Cygnal::probePeers(std::vector<boost::shared_ptr<peer_t> > &peers)
 
 // 	createClient();
     std::vector<boost::shared_ptr<Cygnal::peer_t> >::iterator it;
-    for (it = peers.begin(); it != peers.end(); it++) {
+    for (it = peers.begin(); it != peers.end(); ++it) {
 	boost::shared_ptr<Cygnal::peer_t> peer = *it;
 	probePeers(*peer);
 	if (peer->connected) {
-	    log_network("%s is active on fd #%d.", peer->hostname,
+	    log_network(_("%s is active on fd #%d."), peer->hostname,
 			peer->fd);
  	    _active_peers.push_back(*it);
 	}
@@ -395,7 +396,7 @@ void
 Cygnal::dump()
 {
     std::vector<boost::shared_ptr<Cygnal::peer_t> >::iterator it;
-    for (it = _peers.begin(); it != _peers.end(); it++) {
+    for (it = _peers.begin(); it != _peers.end(); ++it) {
 	cerr << "Remote Peer: " << (*it)->hostname
 	     << ":" << (*it)->port << endl;
     }
@@ -472,7 +473,7 @@ main(int argc, char *argv[])
 	      break;
 	  case 'v':
 	      dbglogfile.setVerbosity();
-	      LOG_ONCE(log_network (_("Verbose output turned on")))
+	      LOG_ONCE(log_network(_("Verbose output turned on")))
 	      break;
 	  case 'p':
 	      port_offset = parser.argument<int>(i);
@@ -496,11 +497,11 @@ main(int argc, char *argv[])
 	      exit(EXIT_SUCCESS);
 	      break;
 	  default:
-	      log_error (_("Extraneous argument: %s"), parser.argument(i).c_str());
+	      log_error(_("Extraneous argument: %s"), parser.argument(i).c_str());
         }
     }
     
-    log_network (_("Document Root for media files is: %s"), docroot);
+    log_network(_("Document Root for media files is: %s"), docroot);
     crcfile.setDocumentRoot(docroot);
     
     // load the file of peers. A peer is another instance of Cygnal we
@@ -582,7 +583,7 @@ main(int argc, char *argv[])
     // Wait for all the threads to die.
     alldone.wait(lk);
     
-    log_network (_("Cygnal done..."));
+    log_network(_("Cygnal done..."));
 
     // Delete the data we allowcated to pass to each connection_handler.
     delete rtmp_data;
@@ -618,7 +619,7 @@ version_and_copyright()
         << _("Copyright (C) 2007, 2008, 2009, 2010 Free Software Foundation, Inc.\n"
         "Cygnal comes with NO WARRANTY, to the extent permitted by law.\n"
         "You may redistribute copies of Cygnal under the terms of the GNU General\n"
-        "Public License V3. For more information, see the file named COPYING.\n")
+        "Public License V3 or later. For more information, see the file named COPYING.\n")
     << endl;
 }
 
@@ -632,7 +633,6 @@ admin_handler(Network::thread_params_t *args)
 
     map<int, Handler *>::iterator hit;
     stringstream response;
-    int index = 0;
     
     Network net;
     Handler::admin_cmd_e cmd = Handler::POLL;
@@ -648,7 +648,7 @@ admin_handler(Network::thread_params_t *args)
 	    const char *ptr = reinterpret_cast<const char *>(data);
 	    ret = net.readNet(data, ADMINPKTSIZE, 100);
 	    if (ret < 0) {
-		log_network("no more admin data, exiting...\n");
+		log_network(_("no more admin data, exiting...\n"));
 		if ((ret == 0) && cmd != Handler::POLL) {
 		    break;
 		}
@@ -694,17 +694,14 @@ admin_handler(Network::thread_params_t *args)
 			       << "," << hand->outsize()
 			       << "\r\n";
 		      net.writeNet(response);
-		      index++;
 		  }
 #endif
 	      }
-	      index = 0;
 	      break;
 	      case Handler::POLL:
 #ifdef USE_STATS_QUEUE
-		  index = 0;
 		  response << handlers.size() << " handlers are currently active." << "\r\n";
- 		  for (hit = handlers.begin(); hit != handlers.end(); hit++) {
+ 		  for (hit = handlers.begin(); hit != handlers.end(); ++hit) {
 		      int fd = hit->first;
  		      Handler *hand = hit->second;
 		      struct timespec now;
@@ -726,9 +723,7 @@ admin_handler(Network::thread_params_t *args)
 			       << "," << stats->totalout
 			       << "\r\n";
  		      net.writeNet(response.str());
-		      index++;
 		  }
-		  index = 0;
 #endif
 		  break;
 	      case Handler::INTERVAL:
@@ -738,7 +733,7 @@ admin_handler(Network::thread_params_t *args)
 		  break;
 	    };
 	} while (ret > 0);
-        log_network("admin_handler: Done...!\n");
+        log_network(_("admin_handler: Done...!\n"));
 	net.closeNet();		// this shuts down this socket connection
     }
     net.closeConnection();		// this shuts down the server on this connection
@@ -767,11 +762,11 @@ connection_handler(Network::thread_params_t *args)
     // Start a server on this tcp/ip port.
     fd = net.createServer(args->port);
     if (fd <= 0) {
-	log_error("Can't start %s Connection Handler for fd #%d, port %hd",
+	log_error(_("Can't start %s Connection Handler for fd #%d, port %hd"),
 		  proto_str[args->protocol], fd, args->port);
 	return;
     } else {
-	log_network("Starting %s Connection Handler for fd #%d, port %hd",
+	log_network(_("Starting %s Connection Handler for fd #%d, port %hd"),
 		    proto_str[args->protocol], fd, args->port);
     }
 
@@ -782,7 +777,7 @@ connection_handler(Network::thread_params_t *args)
     // handling part of the total active file descriptors.
 #ifdef HAVE_SYSCONF
     long ncpus = sysconf(_SC_NPROCESSORS_ONLN);
-    LOG_ONCE(log_network("This system has %d cpus.", ncpus));
+    LOG_ONCE(log_network(_("This system has %d cpus."), ncpus));
 #endif	
     size_t nfds = crcfile.getFDThread();
     
@@ -819,10 +814,11 @@ connection_handler(Network::thread_params_t *args)
 	// things when you have a heavily threaded application.
 	args->netfd = net.newConnection(true, fd);
 	if (args->netfd <= 0) {
-	    log_network("No new %s network connections", proto_str[args->protocol]);
+	    log_network(_("No new %s network connections"),
+                        proto_str[args->protocol]);
 	    continue;
 	} else {
-	    log_network("*** New %s network connection for thread ID #%d, fd #%d ***",
+	    log_network(_("*** New %s network connection for thread ID #%d, fd #%d ***"),
 			proto_str[args->protocol], tid, args->netfd);
 	}
 
@@ -868,7 +864,7 @@ connection_handler(Network::thread_params_t *args)
 		    }
 		} while (retries);
 		string &key = hand->getKey(args->netfd);
-		log_network("Creating new %s Handler for %s using fd #%d",
+		log_network(_("Creating new %s Handler for %s using fd #%d"),
 			    proto_str[hargs->protocol], key, hargs->netfd);
 		hargs->handler = hand;
 		hargs->buffer = buf;
@@ -886,7 +882,7 @@ connection_handler(Network::thread_params_t *args)
 		    // We're done, close this network connection
 		}
 	    } else {
-		log_network("Resuing %s Handler for %s using fd #%d",
+		log_network(_("Reusing %s Handler for %s using fd #%d"),
 			    proto_str[hargs->protocol], key, hargs->netfd);
 		hand->addClient(args->netfd, Network::HTTP);
 	    }
@@ -912,7 +908,7 @@ connection_handler(Network::thread_params_t *args)
 	    string key = url.hostname() + url.path();
 	    boost::shared_ptr<Handler> hand = cyg.findHandler(url.path());
 	    if (!hand) {
-		log_network("Creating new %s Handler for: %s for fd %#d",
+		log_network(_("Creating new %s Handler for: %s for fd %#d"),
 			    proto_str[args->protocol], key, args->netfd);
 		hand.reset(new Handler);
 		cyg.addHandler(key, hand);
@@ -936,7 +932,7 @@ connection_handler(Network::thread_params_t *args)
 		}
 		if (crcfile.getCgiRoot().size() > 0) {
 		    cgiroot += ":" + crcfile.getCgiRoot();
-		    log_network (_("Cygnal Plugin paths are: %s"), cgiroot);
+		    log_network(_("Cygnal Plugin paths are: %s"), cgiroot);
 		} else {
 		    cgiroot = PLUGINSDIR;
 		}
@@ -957,7 +953,7 @@ connection_handler(Network::thread_params_t *args)
 			net.closeNet(args->netfd);
 		    }
 		} else {
-		    log_error("Couldn't load plugin for %s", key); 
+		    log_error(_("Couldn't load plugin for %s"), key); 
 		}
 		
 		// // We're done, close this network connection
@@ -968,10 +964,11 @@ connection_handler(Network::thread_params_t *args)
 	    // delete rtmp;
 	} // end of if RTMP	
 	
-	log_network("Number of active Threads is %d", tids.num_of_tids());
+	log_network(_("Number of active Threads is %d"), tids.num_of_tids());
 	
 //	net.closeNet(args->netfd); 		// this shuts down this socket connection
-	log_network("Restarting loop for next connection for port %d...", args->port);
+	log_network(_("Restarting loop for next connection for port %d..."),
+                    args->port);
     } while(!done);
 
     // All threads should wake up now.
@@ -1028,7 +1025,7 @@ event_handler(Network::thread_params_t *args)
 	// 0 is a reserved stream, so we start with 1, as the reserved
 	// stream isn't one we care about here.
 	if (hand->getActiveDiskStreams()) {
-	    log_network("%d active disk streams",
+	    log_network(_("%d active disk streams"),
 			hand->getActiveDiskStreams());
 	    // hand->dump();
 	}
@@ -1068,11 +1065,11 @@ event_handler(Network::thread_params_t *args)
 	for (int i=0; i <= max + 1; i++) {
 	    if (FD_ISSET(i, &hits)) {
 		FD_CLR(i, &hits);
-		log_network("Got a hit for fd #%d, protocol %s", i,
+		log_network(_("Got a hit for fd #%d, protocol %s"), i,
 			    proto_str[hand->getProtocol(i)]);
 		switch (hand->getProtocol(i)) {
 		  case Network::NONE:
-		      log_error("No protocol specified!");
+		      log_error(_("No protocol specified!"));
 		      break;
 		  case Network::HTTP:
 		  {
@@ -1080,12 +1077,12 @@ event_handler(Network::thread_params_t *args)
 		      // largs.filespec = fullpath;
 		      boost::shared_ptr<HTTPServer> &http = hand->getHTTPHandler(i);
 		      if (!http->http_handler(hand, args->netfd, args->buffer)) {
-			  log_network("Done with HTTP connection for fd #%d, CGI %s", i, args->filespec);
+			  log_network(_("Done with HTTP connection for fd #%d, CGI %s"), i, args->filespec);
 			  net.closeNet(args->netfd);
 			  hand->removeClient(args->netfd);
 			  done = true;
 		      } else {
-			  log_network("Not Done with HTTP connection for fd #%d, it's a persistent connection.", i);
+			  log_network(_("Not Done with HTTP connection for fd #%d, it's a persistent connection."), i);
 			  
 		      }
 		      continue;
@@ -1094,7 +1091,7 @@ event_handler(Network::thread_params_t *args)
 		      args->netfd = i;
 		      // args->filespec = path;
 		      if (!rtmp_handler(args)) {
-			  log_network("Done with RTMP connection for fd #%d, CGI ", i, args->filespec);
+			  log_network(_("Done with RTMP connection for fd #%d, CGI "), i, args->filespec);
 			  done = true;
 		      }
 		      break;
@@ -1105,7 +1102,7 @@ event_handler(Network::thread_params_t *args)
 		      boost::shared_ptr<HTTPServer> &http = hand->getHTTPHandler(i);
 		      // args->filespec = path;
 		      if (!http->http_handler(hand, args->netfd, args->buffer)) {
-			  log_network("Done with HTTP connection for fd #%d, CGI %s", i, largs.filespec);
+			  log_network(_("Done with HTTP connection for fd #%d, CGI %s"), i, largs.filespec);
 			  return;
 		      }		      
 		      break;
@@ -1116,7 +1113,7 @@ event_handler(Network::thread_params_t *args)
 		      // args->filespec = path;
 		      boost::shared_ptr<HTTPServer> &http = hand->getHTTPHandler(i);
 		      if (!http->http_handler(hand, args->netfd, args->buffer)) {
-			  log_network("Done with HTTP connection for fd #%d, CGI %s", i, args->filespec);
+			  log_network(_("Done with HTTP connection for fd #%d, CGI %s"), i, args->filespec);
 			  return;
 		      }		      
 		      break;
@@ -1128,7 +1125,7 @@ event_handler(Network::thread_params_t *args)
 		  case Network::DTN:
 		      break;
 		  default:
-		      log_error("Unsupported network protocol for fd #%d, %d",
+		      log_error(_("Unsupported network protocol for fd #%d, %d"),
 				largs.netfd, hand->getProtocol(i));
 		      done = true;
 		      break;
@@ -1148,7 +1145,7 @@ event_handler(Network::thread_params_t *args)
 	hits = net.waitForNetData(hand->getClients());
 	if (FD_ISSET(0, &hits)) {
 	    FD_CLR(0, &hits);
-	    log_network("Got no hits, %d retries", retries);
+	    log_network(_("Got no hits, %d retries"), retries);
 	    // net.closeNet(args->netfd);
 	    // hand->removeClient(args->netfd);
 	    // done = true;
@@ -1169,5 +1166,5 @@ event_handler(Network::thread_params_t *args)
 
 // local Variables:
 // mode: C++
-// indent-tabs-mode: t
+// indent-tabs-mode: nil
 // End:
