@@ -1,7 +1,7 @@
 // http.cpp:  HyperText Transport Protocol handler for Cygnal, for Gnash.
 // 
-//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010 Free Software
-//   Foundation, Inc
+//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -87,13 +87,13 @@ HTTPServer::~HTTPServer()
 }
 
 HTTP::http_method_e
-HTTPServer::processClientRequest(int fd)
+HTTPServer::processClientRequest(int /* fd */)
 {
     GNASH_REPORT_FUNCTION;
     
-    cygnal::Buffer *buf = new cygnal::Buffer;
-
+    //cygnal::Buffer *buf = new cygnal::Buffer;
     // return processClientRequest(fd, buf);
+    
     return HTTP::HTTP_NONE;
 }
 
@@ -151,7 +151,7 @@ HTTPServer::processClientRequest(Handler *hand, int fd, cygnal::Buffer *buf)
 	filestream->dump();
     } else {
 	filestream.reset(new DiskStream);
-	log_network("New filestream %s", _filespec);
+	log_network(_("New filestream %s"), _filespec);
 	// cache.addFile(url, filestream);	FIXME: always reload from disk for now.
 	
 	// Oopen the file and read the first chunk into memory
@@ -189,10 +189,10 @@ HTTPServer::processGetRequest(Handler *hand, int fd, cygnal::Buffer *buf)
 //    cerr << hexify(buf->reference(), buf->allocated(), false) << endl;
     
     if (buf == 0) {
-     //	log_debug("Que empty, net connection dropped for fd #%d", getFileFd());
-	log_debug("Que empty, net connection dropped for fd #%d", fd);
-	cygnal::Buffer buf;
-	return buf;
+     //	log_debug("Queue empty, net connection dropped for fd #%d", getFileFd());
+	log_debug("Queue empty, net connection dropped for fd #%d", fd);
+//	cygnal::Buffer buf;
+	return _buf;
     }
     
     clearHeader();
@@ -208,9 +208,9 @@ HTTPServer::processGetRequest(Handler *hand, int fd, cygnal::Buffer *buf)
     }
     if (!_diskstream) {
 	_diskstream.reset(new DiskStream);
-	log_network("New filestream %s", _filespec);
+	log_network(_("New filestream %s"), _filespec);
     } else {
-	log_network("Reusing filestream %s", _filespec);
+	log_network(_("Reusing filestream %s"), _filespec);
     }
     
     // Oopen the file and read the first chunk into memory
@@ -270,7 +270,7 @@ HTTPServer::processGetRequest(Handler *hand, int fd, cygnal::Buffer *buf)
 // the header like we normally do, we then read the amount of bytes specified by
 // the "content-length" field, and then write that data to disk, or decode the amf.
 boost::shared_ptr<cygnal::Buffer>
-HTTPServer::processPostRequest(int fd, cygnal::Buffer *bufFIXME)
+HTTPServer::processPostRequest(int fd, cygnal::Buffer * /* bufFIXME */)
 {
     GNASH_REPORT_FUNCTION;
 
@@ -284,7 +284,8 @@ HTTPServer::processPostRequest(int fd, cygnal::Buffer *bufFIXME)
     
     buf = _que.pop();
     if (buf == 0) {
-	log_debug("Que empty, net connection dropped for fd #%d", getFileFd());
+	log_debug("Queue empty, net connection dropped for fd #%d",
+		  getFileFd());
 	return buf;
     }
 //    cerr << __FUNCTION__ << buf->allocated() << " : " << hexify(buf->reference(), buf->allocated(), true) << endl;
@@ -301,6 +302,9 @@ HTTPServer::processPostRequest(int fd, cygnal::Buffer *bufFIXME)
     } else {	
 //	cerr << "Need to read more data, only have "  << buf->allocated() << " bytes" << endl;
 	ret = readNet(fd, *content, 2);
+	if (ret < 0) {
+	    log_error(_("couldn't read data!"));
+	}
 	data = content->reference();
     }    
     
@@ -366,7 +370,7 @@ HTTPServer::processPutRequest(int /* fd */, cygnal::Buffer */* buf */)
 {
     boost::shared_ptr<cygnal::Buffer> buf;
 //    GNASH_REPORT_FUNCTION;
-    log_unimpl("PUT request");
+    log_unimpl(_("PUT request"));
 
     return buf;
 }
@@ -376,7 +380,7 @@ HTTPServer::processDeleteRequest(int /* fd */, cygnal::Buffer */* buf */)
 {
 //    GNASH_REPORT_FUNCTION;
     boost::shared_ptr<cygnal::Buffer> buf;
-    log_unimpl("DELETE request");
+    log_unimpl(_("DELETE request"));
     
     return buf;
 }
@@ -386,7 +390,7 @@ HTTPServer::processConnectRequest(int /* fd */, cygnal::Buffer */* buf */)
 {
 //    GNASH_REPORT_FUNCTION;
     boost::shared_ptr<cygnal::Buffer> buf;
-    log_unimpl("CONNECT request");
+    log_unimpl(_("CONNECT request"));
 
     return buf;
 }
@@ -396,7 +400,7 @@ HTTPServer::processOptionsRequest(int /* fd */, cygnal::Buffer */* buf */)
 {
 //    GNASH_REPORT_FUNCTION;
     boost::shared_ptr<cygnal::Buffer> buf;
-    log_unimpl("OPTIONS request");
+    log_unimpl(_("OPTIONS request"));
 
     return buf;
 }
@@ -406,7 +410,7 @@ HTTPServer::processHeadRequest(int /* fd */, cygnal::Buffer */* buf */)
 {
 //    GNASH_REPORT_FUNCTION;
     boost::shared_ptr<cygnal::Buffer> buf;
-    log_unimpl("HEAD request");
+    log_unimpl(_("HEAD request"));
     
     return buf;
 }
@@ -416,7 +420,7 @@ HTTPServer::processTraceRequest(int /* fd */, cygnal::Buffer */* buf */)
 {
 //    GNASH_REPORT_FUNCTION;
     boost::shared_ptr<cygnal::Buffer> buf;
-    log_unimpl("TRACE request");
+    log_unimpl(_("TRACE request"));
     
     return buf;
 }
@@ -481,11 +485,11 @@ HTTPServer::formatGetReply(size_t size, http_status_e code)
 
 #if 0
     if (_header.str().size()) {
-        log_debug (_("Sent GET Reply"));
+        log_debug ("Sent GET Reply");
 	return _buffer;
     } else {
 	clearHeader();
-	log_debug (_("Couldn't send GET Reply, no header data"));
+	log_debug ("Couldn't send GET Reply, no header data");
     }    
 #endif
     
@@ -513,11 +517,11 @@ HTTPServer::formatPostReply(rtmpt_cmd_e /* code */)
 	buf->copy(str);
 	_handler->pushout(buf);
 	_handler->notifyout();
-        log_debug (_("Sent GET Reply"));
+        log_debug ("Sent GET Reply");
 	return true; // Default to true
     } else {
 	clearHeader();
-	log_debug (_("Couldn't send POST Reply, no header data"));
+	log_debug ("Couldn't send POST Reply, no header data");
     }
 #endif
 
@@ -881,7 +885,7 @@ HTTPServer::extractCommand(boost::uint8_t *data)
 	// in it. It's actually two separate integers.
 	_version.major = *(end+6) - '0';
 	_version.minor = *(end+8) - '0';
-	// log_debug (_("Version: %d.%d"), _version.major, _version.minor);
+	// log_debug("Version: %d.%d", _version.major, _version.minor);
     }
 
     return cmd;
@@ -911,7 +915,8 @@ HTTPServer::processHeaderFields(cygnal::Buffer &buf)
 		_keepalive = true;
 		if ((value != "on") && (value != "off")) {
 		    _max_requests = strtol(value.c_str(), NULL, 0);
-		    log_debug("Setting Max Requests for Keep-Alive to %d", _max_requests);
+		    log_debug("Setting Max Requests for Keep-Alive to %d",
+			      _max_requests);
 		}
 	    }
 	    if (name == "connection") {
@@ -955,7 +960,7 @@ HTTPServer::processHeaderFields(cygnal::Buffer &buf)
 		    // in it. It's actually two separate integers.
 		    _version.major = i->at(pos+5) - '0';
 		    _version.minor = i->at(pos+7) - '0';
-		    // log_debug (_("Version: %d.%d"), _version.major, _version.minor);
+		    // log_debug ("Version: %d.%d", _version.major, _version.minor);
 		    // the filespec in the request is the middle field, deliminated
 		    // by a space on each end.
 		    if (params != string::npos) {
@@ -967,7 +972,7 @@ HTTPServer::processHeaderFields(cygnal::Buffer &buf)
 		    }
 		    // log_debug("Requesting file: \"%s\"", _filespec);
 
-		    // HTTP 1.1 enables persistant network connections
+		    // HTTP 1.1 enables persistent network connections
 		    // by default.
 		    if (_version.minor > 0) {
 			log_debug("Enabling Keep Alive by default for HTTP > 1.0");
@@ -1005,7 +1010,7 @@ HTTPServer::http_handler(Handler *hand, int netfd, cygnal::Buffer *buf)
     // by default, only look once unless changed later
     // www->setDocRoot(crcfile.getDocumentRoot());
     // log_network("Docroot for HTTP files is %s", crcfile.getDocumentRoot());
-    log_network("Processing HTTP data for fd #%d", netfd);
+    log_network(_("Processing HTTP data for fd #%d"), netfd);
     
     // Wait for data, and when we get it, process it.
 #ifdef USE_STATISTICS
@@ -1014,9 +1019,9 @@ HTTPServer::http_handler(Handler *hand, int netfd, cygnal::Buffer *buf)
 #endif
 
     if (buf) {
-	log_network("FIXME: Existing data in packet!");
+	log_network(_("FIXME: Existing data in packet!"));
     } else {
-	log_network("FIXME: No existing data in packet!");    
+	log_network(_("FIXME: No existing data in packet!"));
 	// See if we have any messages waiting
 	if (recvMsg(netfd) == 0) {
 	    log_debug("Net HTTP server failed to read from fd #%d...", netfd);
@@ -1027,10 +1032,12 @@ HTTPServer::http_handler(Handler *hand, int netfd, cygnal::Buffer *buf)
     // Process incoming messages
     HTTP::http_method_e cmd = processClientRequest(hand, netfd, buf);    
     if (cmd != HTTP::HTTP_GET) {
-	log_debug("No active DiskStreams for fd #%d: %s...", netfd, _filespec);
+	log_debug("No active DiskStreams for fd #%d: %s...", netfd,
+		  _filespec);
     } else {
 	if (_diskstream) {
-	    log_debug("Found active DiskStream! for fd #%d: %s", netfd, _filespec);
+	    log_debug("Found active DiskStream! for fd #%d: %s", netfd,
+		      _filespec);
 	    hand->setDiskStream(netfd, _diskstream);
  	    cache.addFile(_filespec, _diskstream);
 // Send the first chunk of the file to the client.
