@@ -41,10 +41,15 @@
 #endif
 
 // Cairo support for rendering in the canvas.
-#ifdef HAVE_CAIRO_H
+#ifdef RENDERER_CAIRO
 #include "gtk_glue_cairo.h"
 #endif
 
+// Cairo support for rendering in the canvas.
+#ifdef RENDERER_OPENVG
+#include "gtk_glue_ovg.h"
+#endif
+
 // AGG support, which is the default, for rendering in the canvas.
 #include "gtk_glue_agg.h"
 
@@ -116,7 +121,7 @@ gnash_canvas_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
     GnashCanvas *canvas = GNASH_CANVAS(widget);
 
     gnash::log_debug("gnash_canvas_size_allocate %d %d", allocation->width,
-            allocation->height);
+                allocation->height);
 
     if (canvas->renderer.get()) {
         canvas->glue->setRenderHandlerSize(allocation->width,
@@ -209,6 +214,8 @@ gnash_canvas_setup(GnashCanvas *canvas, std::string& hwaccel,
         renderer = "cairo";
 #elif defined (RENDERER_OGL)
         renderer = "opengl";
+#elif defined (RENDERER_OPENVG)
+        renderer = "openvg";
 #endif
     }
 
@@ -243,6 +250,16 @@ gnash_canvas_setup(GnashCanvas *canvas, std::string& hwaccel,
         boost::format fmt = boost::format("Support for renderer %1% "
                 " was not built") % renderer;
         throw gnash::GnashException(fmt.str());
+#endif
+    }
+    else if ((renderer == "openvg") || (renderer == "ovg")) {
+	renderer = "openvg";
+#ifdef RENDERER_OPENVG
+        canvas->glue.reset(new gnash::gui::GtkOvgGlue);
+#else
+        boost::format fmt = boost::format("Support for renderer %1% "
+                " was not built") % renderer;
+        throw gnash::GnashException(fmt.str());
 #endif
     }
     else if (renderer == "agg") {
@@ -254,6 +271,7 @@ gnash_canvas_setup(GnashCanvas *canvas, std::string& hwaccel,
         // rendering performance issues.
         // Use LibVva, which works on Nvidia, AT, or Intel 965 GPUs
         // with AGG or OpenGL.
+#ifdef RENDERER_AGG
 #ifdef HAVE_VA_VA_H
         if (hwaccel == "vaapi") {
             canvas->glue.reset(new gnash::GtkAggVaapiGlue);
@@ -261,7 +279,6 @@ gnash_canvas_setup(GnashCanvas *canvas, std::string& hwaccel,
             // if initializing fails.
         } else
 #endif
-#ifdef RENDERER_AGG
         {
             canvas->glue.reset(new gnash::GtkAggGlue);
         }
