@@ -1,7 +1,7 @@
 // extension.cpp:  Read and enable plug-in extensions to Flash, for Gnash.
 // 
-//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010 Free Software
-//   Foundation, Inc
+//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -22,27 +22,15 @@
 #include "gnashconfig.h"
 #endif
 
-// #if defined(_WIN32) || defined(WIN32)
-// # define lock(lib_mutex);
-// # define scoped_lock ;
-// #define PLUGINSDIR "./"    //hack
-// #define USE_DIRENT 1
-// #else
-// # include <boost/detail/lightweight_mutex.hpp>
-//   using boost::detail::lightweight_mutex;
-// # define scoped_lock lightweight_mutex::scoped_lock
-//   static lightweight_mutex lib_mutex;
-// #endif
-
 #if defined(WIN32) || defined(_WIN32)
 #define LIBLTDL_DLL_IMPORT 1
 #endif
 #include <cstring>
 #include <iostream>
 #include <sys/types.h>
+#include <ltdl.h>
 
 #include "log.h"
-#include "ltdl.h"
 #include "sharedlib.h"
 #include "extension.h"
 
@@ -52,12 +40,6 @@ namespace gnash {
 
 #if defined(WIN32) || defined(_WIN32)
 int        lt_dlsetsearchpath   (const char *search_path);
-int        lt_dlinit           (void);
-void *     lt_dlsym            (lt_dlhandle handle, const char *name);
-const char *lt_dlerror         (void);
-int        lt_dlclose          (lt_dlhandle handle);
-int        lt_dlmakeresident   (lt_dlhandle handle);
-lt_dlhandle lt_dlopenext       (const char *filename);
 #endif
 
 #if HAVE_DIRENT_H || WIN32==1    // win32 hack
@@ -81,11 +63,6 @@ namespace gnash {
 
 Extension::Extension() 
 {
-//    GNASH_REPORT_FUNCTION;
-#ifdef LT_DLMUTEX
-//     return lt_dlmutex_register (gnash_mutex_lock, gnash_mutex_unlock,
-//                                 gnash_mutex_seterror, gnash_mutex_geterror);
-#endif
     char *env = std::getenv("GNASH_PLUGINS");
     if (!env) {
         _pluginsdir = PLUGINSDIR;
@@ -95,23 +72,19 @@ Extension::Extension()
     }
 
     log_debug("Plugins path: %s", _pluginsdir);
+#ifdef HAVE_LTDL
     lt_dlsetsearchpath(_pluginsdir.c_str());
+#endif
 }
 
 Extension::Extension(const std::string& dir)
 {
 //    GNASH_REPORT_FUNCTION;
-#ifdef LT_DLMUTEX
-//     return lt_dlmutex_register (gnash_mutex_lock, gnash_mutex_unlock,
-//                                 gnash_mutex_seterror, gnash_mutex_geterror);
-#endif
     _pluginsdir = dir;
-    lt_dlsetsearchpath(_pluginsdir.c_str());
-}
 
-Extension::~Extension()
-{
-//    GNASH_REPORT_FUNCTION;
+#ifdef HAVE_LTDL
+    lt_dlsetsearchpath(_pluginsdir.c_str());
+#endif
 }
 
 bool
@@ -119,7 +92,9 @@ Extension::scanAndLoad(const std::string& dir, as_object &obj)
 {
 //    GNASH_REPORT_FUNCTION;
     
+#ifdef HAVE_LTDL
     lt_dlsetsearchpath(_pluginsdir.c_str());
+#endif
     _pluginsdir = dir;
     
     return scanAndLoad(obj);
@@ -135,7 +110,7 @@ Extension::scanAndLoad(as_object& where)
     }
     
     std::vector<std::string>::iterator it;
-    for (it = _modules.begin(); it != _modules.end(); it++) {
+    for (it = _modules.begin(); it != _modules.end(); ++it) {
         const std::string& mod = *it;
         log_security(_("Loading module: %s from %s"), mod, _pluginsdir);
         initModule(mod, where);
@@ -153,7 +128,7 @@ Extension::initModule(const std::string& module, as_object &where)
     log_security(_("Initializing module: \"%s\" from %s"), symbol, _pluginsdir);
     
     if (_plugins[module] == 0) {
-        sl = new SharedLib(_pluginsdir + "/" + module, "GNASH_PLUGINS");
+        sl = new SharedLib(_pluginsdir + "/" + module);
         sl->openLib();
         _plugins[module] = sl;
     } else {
@@ -220,7 +195,7 @@ Extension::scanDir(const std::string& dirlist)
 
         const std::string& dir = *i;
 
-        log_debug(_("Scanning directory \"%s\" for plugins"), dir);
+        log_debug("Scanning directory \"%s\" for plugins", dir);
         DIR *libdir = opendir(dir.c_str());
 
         if (!libdir) {
@@ -248,7 +223,7 @@ Extension::scanDir(const std::string& dirlist)
             name.erase(pos);
 
             if (suffix == ".so") {
-                log_debug(_("Gnash Plugin name: %s"), name);
+                log_debug("Gnash Plugin name: %s", name);
                 _modules.push_back(name);
             }
             else {
@@ -270,7 +245,7 @@ Extension::dumpModules()
     
     std::cerr << _modules.size() << " plugin(s) for Gnash installed" << std::endl;    
     std::vector<std::string>::iterator it;
-    for (it = _modules.begin(); it != _modules.end(); it++) {
+    for (it = _modules.begin(); it != _modules.end(); ++it) {
         std::cerr << "Module name is: \"" << *(it) << "\"" << std::endl;
     }
 }
