@@ -1,5 +1,6 @@
 // 
-//   Copyright (C) 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
+//   Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc.
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -15,7 +16,6 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-#include "smart_ptr.h"
 #include "DynamicShape.h"
 #include "FillStyle.h"
 #include "Renderer.h"
@@ -45,9 +45,9 @@ DynamicShape::clear()
 }
 
 void
-DynamicShape::display(Renderer& renderer, const DisplayObject& inst) const
+DynamicShape::display(Renderer& renderer, const Transform& xform) const
 {
-    renderer.drawShape(_shape, inst.get_world_cxform(), inst.getWorldMatrix());
+    renderer.drawShape(_shape, xform);
 }
 
 void
