@@ -1,6 +1,7 @@
 // GnashKey.h: map sets of keycodes to each other.
 // 
-//   Copyright (C) 2005, 2006, 2007, 2008, 2009 Free Software Foundation, Inc.
+//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -37,7 +38,7 @@ enum modifier
     GNASH_MOD_ALT = 4
 };
 
-// Gnash character codes. Each code represents a single character on the keyboard.
+// Gnash DisplayObject codes. Each code represents a single DisplayObject on the keyboard.
 // The first 128 code are ordered by their correspond ASCII value.
 enum code
 {
@@ -214,7 +215,7 @@ enum code
 
   KP_ADD = 162,
   KP_SUBTRACT = 163,
-  KP_MULITPLY = 164,
+  KP_MULTIPLY = 164,
   KP_DIVIDE = 165,
   KP_DECIMAL = 166,
   KP_ENTER = 167,
@@ -320,7 +321,7 @@ enum code
   thorn = 263,
   yDIAERESIS = 264,
   
-  // TODO: add other function keys and characters not yet known.
+  // TODO: add other function keys and DisplayObjects not yet known.
   HELP = 265,
   KEYCOUNT
 };
