@@ -1,6 +1,6 @@
 // 
-//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010,
-//   2011 Free Software Foundation, Inc
+//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -102,7 +102,7 @@ MovieLoader::processRequests()
 #endif
 
 #ifdef GNASH_DEBUG_LOCKING
-        log_debug("processRequests: lock on requests: release");
+            log_debug("processRequests: lock on requests: release");
 #endif
 
             continue;
@@ -188,7 +188,7 @@ MovieLoader::clear()
         _wakeup.notify_all(); // in case it was sleeping
 
 #ifdef GNASH_DEBUG_LOCKING
-        log_debug("clear: lock on requests: release ater notify_all");
+        log_debug("clear: lock on requests: release after notify_all");
 #endif
         requestsLock.unlock(); // allow the thread to die
 
@@ -273,14 +273,14 @@ MovieLoader::processCompletedRequest(const Request& r)
         unsigned int levelno;
         const int version = _movieRoot.getVM().getSWFVersion();
         if (isLevelTarget(version, target, levelno)) {
-            log_debug(_("processCompletedRequest: _level loading "
-                    "(level %u)"), levelno);
+            log_debug("processCompletedRequest: _level loading "
+                    "(level %u)", levelno);
 	        extern_movie->set_depth(levelno + DisplayObject::staticDepthOffset);
             _movieRoot.setLevel(levelno, extern_movie);
         }
         else {
             log_debug("Target %s of a loadMovie request doesn't exist at "
-                  "load complete time", target);
+                        "load complete time", target);
             return true;
         }
     }
@@ -379,21 +379,21 @@ MovieLoader::processCompletedRequests()
 
 #ifdef GNASH_DEBUG_LOCKING
         log_debug("processCompletedRequests: lock on requests for removal: "
-                  "trying");
+                    "trying");
 #endif
 
         requestsLock.lock();
 
 #ifdef GNASH_DEBUG_LOCKING
         log_debug("processCompletedRequests: lock on requests for removal: "
-                  "obtained");
+                  "obtained")
 #endif
 
         _requests.erase(it);
 
 #ifdef GNASH_DEBUG_LOCKING
         log_debug("processCompletedRequests: lock on requests for removal: "
-                  "release");
+                    "release");
 #endif
     }
 }
@@ -437,13 +437,13 @@ MovieLoader::loadMovie(const std::string& urlstr,
                                                                      : 0;
 
 #ifdef GNASH_DEBUG_LOCKING
-log_debug("loadMovie: lock on requests: trying");
+    log_debug("loadMovie: lock on requests: trying");
 #endif
 
     boost::mutex::scoped_lock lock(_requestsMutex);
 
 #ifdef GNASH_DEBUG_LOCKING
-log_debug("loadMovie: lock on requests: obtained");
+    log_debug("loadMovie: lock on requests: obtained");
 #endif
 
     _requests.push_front(
