@@ -1,6 +1,7 @@
 // SystemClock.cpp -- system-time based VirtualClock for gnash core lib
 // 
-//   Copyright (C) 2005, 2006, 2007, 2008, 2009 Free Software Foundation, Inc.
+//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -17,42 +18,37 @@
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 // 
 
-#ifdef HAVE_CONFIG_H
-#include "gnashconfig.h"
-#endif
-
 #include "SystemClock.h"
 
 #include "ClockTime.h" // for getting system time
 
 #include <boost/cstdint.hpp> // for boost::uint64_t typedef
 
-namespace gnash
-{
+namespace gnash {
+
+namespace {
 
-/* static private */
 boost::uint64_t
-SystemClock::fetchSystemTime() 
+fetchSystemTime() 
 {
-    // Time::getTicks always returns milliseconds
+    // ClockTime::getTicks always returns milliseconds
     return clocktime::getTicks();
 }
 
-/* public */
+}
+
 SystemClock::SystemClock() 
 	:
 	_startTime(fetchSystemTime())
 {
 }
 
-/* public */
 unsigned long int
 SystemClock::elapsed() const
 {
     return fetchSystemTime() - _startTime;
 }
 
-/* public */
 void
 SystemClock::restart()
 {
