@@ -1,7 +1,7 @@
 // Date_as.cpp:  ActionScript class for date and time, for Gnash.
 // 
-//  Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010,
-//   2011 Free SoftwareFoundation, Inc
+//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
+//   Free SoftwareFoundation, Inc
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -1162,7 +1162,7 @@ date_setMilliseconds(const fn_call& fn)
 
         if (fn.nargs > 1) {
             IF_VERBOSE_ASCODING_ERRORS(
-                log_aserror(_("Date.setMilliseconds was called with more "
+                log_aserror(_("Date.set%sMilliseconds was called with more "
                              "than one argument"), utc ? "UTC" : "");
             )
         }
