@@ -1,6 +1,6 @@
 // 
-//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010 Free Software
-//   Foundation, Inc
+//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -25,21 +25,18 @@
 #define __STDC_CONSTANT_MACROS
 #endif
 
-#include "MediaParser.h"
-#include "PlayHead.h" // for composition
-
-#include "VideoDecoder.h" // for visibility of dtor
-#include "AudioDecoder.h" // for visibility of dtor
-
-#include "VirtualClock.h"
-
-#include "Relay.h" // for ActiveRelay inheritance
-
 #include <boost/intrusive_ptr.hpp>
 #include <string>
-#include <deque>
+#include <boost/ptr_container/ptr_deque.hpp>
 #include <boost/scoped_ptr.hpp>
 
+#include "MediaParser.h"
+#include "PlayHead.h" // for composition
+#include "VideoDecoder.h" // for visibility of dtor
+#include "AudioDecoder.h" // for visibility of dtor
+#include "VirtualClock.h"
+#include "Relay.h" // for ActiveRelay inheritance
+
 // Forward declarations
 namespace gnash {
     class CharacterProxy;
@@ -110,7 +107,7 @@ public:
         boost::uint8_t* m_ptr;
     };
 
-    typedef std::deque<CursoredBuffer*> AudioQueue;
+    typedef boost::ptr_deque<CursoredBuffer> AudioQueue;
 
     // Delete all samples in the audio queue.
     void cleanAudioQueue();
@@ -272,7 +269,7 @@ public:
     //
     /// @return The size of the buffer in milliseconds.
     ///
-    boost::uint32_t bufferTime() { return m_bufferTime; }
+    boost::uint32_t bufferTime() { return _bufferTime; }
 
     /// Returns the number of bytes of the media file that have been buffered.
     long bytesLoaded();
@@ -291,17 +288,12 @@ public:
     ///
     long bufferLength();
 
-    /// Tells us if there is a new video frame ready
-    //
-    /// @return true if a frame is ready, false if not
-    bool newFrameReady();
-
     /// Returns the video frame closest to current cursor. See time().
     //
     /// @return a image containing the video frame, a NULL auto_ptr if
     /// none were ready
     ///
-    std::auto_ptr<GnashImage> get_video();
+    std::auto_ptr<image::GnashImage> get_video();
     
     /// Register the DisplayObject to invalidate on video updates
     void setInvalidatedVideo(DisplayObject* ch)
@@ -321,7 +313,7 @@ public:
     static unsigned int audio_streamer(void *udata, boost::int16_t* samples,
             unsigned int nSamples, bool& eof);
 
-protected:
+private:
     
     /// Status codes used for notifications
     enum StatusCode {
@@ -354,78 +346,6 @@ protected:
         invalidTime
     };
 
-    NetConnection_as* _netCon;
-
-    boost::scoped_ptr<CharacterProxy> _audioController;
-
-    /// Set stream status.
-    //
-    /// Valid statuses are:
-    ///
-    /// Status level:
-    ///  - NetStream.Buffer.Empty
-    ///  - NetStream.Buffer.Full
-    ///  - NetStream.Buffer.Flush
-    ///  - NetStream.Play.Start
-    ///  - NetStream.Play.Stop 
-    ///  - NetStream.Seek.Notify 
-    ///
-    /// Error level:
-    ///  - NetStream.Play.StreamNotFound
-    ///  - NetStream.Seek.InvalidTime
-    ///
-    /// This method locks the statusMutex during operations
-    ///
-    void setStatus(StatusCode code);
-
-    /// \brief
-    /// Call any onStatus event handler passing it
-    /// any queued status change, see _statusQueue
-    //
-    /// Will NOT lock the statusMutex itself, rather it will
-    /// iteratively call the popNextPendingStatusNotification()
-    /// private method, which will take care of locking it.
-    /// This is to make sure onStatus handler won't call methods
-    /// possibly trying to obtain the lock again (::play, ::pause, ...)
-    ///
-    void processStatusNotifications();
-    
-    // The size of the buffer in milliseconds
-    boost::uint32_t m_bufferTime;
-
-    // Are a new frame ready to be returned?
-    volatile bool m_newFrameReady;
-
-    // Mutex to insure we don't corrupt the image
-    boost::mutex image_mutex;
-
-    // The image/videoframe which is given to the renderer
-    std::auto_ptr<GnashImage> m_imageframe;
-
-    // The video URL
-    std::string url;
-
-    // The input media parser
-    std::auto_ptr<media::MediaParser> m_parser;
-
-    // Are we playing a FLV?
-    // The handler which is invoked on status change
-    boost::intrusive_ptr<as_function> _statusHandler;
-
-    // The position in the inputfile, only used when not playing a FLV
-    long inputPos;
-
-    /// Unplug the advance timer callback
-    void stopAdvanceTimer();
-
-    /// Register the advance timer callback
-    void startAdvanceTimer();
-
-    /// The DisplayObject to invalidate on video updates
-    DisplayObject* _invalidatedVideoCharacter;
-
-private:
-
     enum DecodingState {
         DEC_NONE,
         DEC_STOPPED,
@@ -499,15 +419,11 @@ private:
     /// and up to current timestamp
     void refreshAudioBuffer();
 
-    /// Used to decode and push the next available (non-FLV) frame to
-    /// the audio or video queue
-    bool decodeMediaFrame();
-
     /// Decode next video frame fetching it MediaParser cursor
     //
     /// @return 0 on EOF or error, a decoded video otherwise
     ///
-    std::auto_ptr<GnashImage> decodeNextVideoFrame();
+    std::auto_ptr<image::GnashImage> decodeNextVideoFrame();
 
     /// Decode next audio frame fetching it MediaParser cursor
     //
@@ -530,7 +446,7 @@ private:
     /// 3. next element in cursor has timestamp > tx
     /// 4. there was an error decoding
     ///
-    std::auto_ptr<GnashImage> getDecodedVideoFrame(boost::uint32_t ts);
+    std::auto_ptr<image::GnashImage> getDecodedVideoFrame(boost::uint32_t ts);
 
     DecodingState decodingStatus(DecodingState newstate = DEC_NONE);
 
@@ -539,6 +455,69 @@ private:
     /// as possible w/out blocking
     void parseNextChunk();
 
+    /// Set stream status.
+    //
+    /// Valid statuses are:
+    ///
+    /// Status level:
+    ///  - NetStream.Buffer.Empty
+    ///  - NetStream.Buffer.Full
+    ///  - NetStream.Buffer.Flush
+    ///  - NetStream.Play.Start
+    ///  - NetStream.Play.Stop 
+    ///  - NetStream.Seek.Notify 
+    ///
+    /// Error level:
+    ///  - NetStream.Play.StreamNotFound
+    ///  - NetStream.Seek.InvalidTime
+    ///
+    /// This method locks the statusMutex during operations
+    ///
+    void setStatus(StatusCode code);
+
+    /// \brief
+    /// Call any onStatus event handler passing it
+    /// any queued status change, see _statusQueue
+    //
+    /// Will NOT lock the statusMutex itself, rather it will
+    /// iteratively call the popNextPendingStatusNotification()
+    /// private method, which will take care of locking it.
+    /// This is to make sure onStatus handler won't call methods
+    /// possibly trying to obtain the lock again (::play, ::pause, ...)
+    ///
+    void processStatusNotifications();
+
+    /// Unplug the advance timer callback
+    void stopAdvanceTimer();
+
+    /// Register the advance timer callback
+    void startAdvanceTimer();
+
+    NetConnection_as* _netCon;
+
+    boost::scoped_ptr<CharacterProxy> _audioController;
+    
+    // The size of the buffer in milliseconds
+    boost::uint32_t _bufferTime;
+
+    // Mutex to insure we don't corrupt the image
+    boost::mutex image_mutex;
+
+    // The image/videoframe which is given to the renderer
+    std::auto_ptr<image::GnashImage> _imageframe;
+
+    // The video URL
+    std::string url;
+
+    // The input media parser
+    std::auto_ptr<media::MediaParser> _parser;
+
+    // The position in the inputfile, only used when not playing a FLV
+    long _inputPos;
+
+    /// The DisplayObject to invalidate on video updates
+    DisplayObject* _invalidatedVideoCharacter;
+
     DecodingState _decoding_state;
 
     // Mutex protecting _playback_state and _decoding_state
@@ -583,7 +562,7 @@ private:
     StatusCode _statusCode;
 
     /// Mutex protecting _statusQueue
-    boost::mutex statusMutex;
+    boost::mutex _statusMutex;
 
 };
 
