@@ -1,6 +1,7 @@
 // BitmapMovieDefinition.cpp:  Bitmap movie definition, for Gnash.
 // 
-//   Copyright (C) 2007, 2008, 2009, 2010, 2011 Free Software Foundation, Inc.
+//   Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc.
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -17,7 +18,6 @@
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 //
 
-#include "smart_ptr.h" 
 #include "BitmapMovie.h"
 #include "BitmapMovieDefinition.h"
 #include "Geometry.h" // for class path and class edge
