@@ -1,5 +1,6 @@
-//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010 Free Software
-//   Foundation, Inc
+//
+//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -20,7 +21,6 @@
 #define GNASH_SWF_SHAPERECORD_H
 
 #include "Geometry.h"
-#include "fill_style.h"
 #include "LineStyle.h"
 #include "SWFRect.h"
 
@@ -30,6 +30,7 @@
 namespace gnash {
     class movie_definition;
     class RunResources;
+    class FillStyle;
 }
 
 namespace gnash {
@@ -52,15 +53,17 @@ class ShapeRecord
 {
 public:
 
-    typedef std::vector<fill_style> FillStyles;
+    typedef std::vector<FillStyle> FillStyles;
     typedef std::vector<LineStyle> LineStyles;
     typedef std::vector<Path> Paths;
 
     /// Construct a ShapeRecord.
     //
+    /// This should only really be used for DynamicShapes.
+    //
     /// Ideally all immutable ShapeRecords should be constructed with the
     /// ctor taking an SWFStream, but some tag formats do not allow this.
-    ShapeRecord() {}
+    ShapeRecord();
 
     /// Construct a ShapeRecord from a SWFStream.
     //
@@ -68,13 +71,13 @@ public:
     ShapeRecord(SWFStream& in, SWF::TagType tag, movie_definition& m,
             const RunResources& r);
 
-    ShapeRecord(const ShapeRecord& other)
-        :
-        _fillStyles(other._fillStyles),
-        _lineStyles(other._lineStyles),
-        _paths(other._paths),
-        _bounds(other._bounds)
-    {}
+    /// Copy constructor
+    ShapeRecord(const ShapeRecord& other);
+    
+    /// Assignment operator
+    ShapeRecord& operator=(const ShapeRecord& other);
+
+    ~ShapeRecord();
 
     /// Parse path data from a SWFStream.
     //
@@ -114,16 +117,9 @@ public:
             const double ratio);
 
     /// Reset all shape data.
-    void clear() {
-        _fillStyles.clear();
-        _lineStyles.clear();
-        _paths.clear();
-        _bounds.set_null();
-    }
+    void clear();
 
-    void addFillStyle(const fill_style& fs) {
-        _fillStyles.push_back(fs);
-    }
+    void addFillStyle(const FillStyle& fs);
 
     void addPath(const Path& path) {
         _paths.push_back(path);
@@ -138,7 +134,7 @@ public:
     }
 
 private:
-    
+
     /// Shape record flags for use in parsing.
     enum ShapeRecordFlags {
         SHAPE_END = 0x00,
@@ -156,6 +152,8 @@ private:
 
 };
 
+std::ostream& operator<<(std::ostream& o, const ShapeRecord& sh);
+
 } // namespace SWF
 } // namespace gnash
 
