@@ -1,6 +1,7 @@
 // StartSoundTag.cpp:  for Gnash.
 //
-//   Copyright (C) 2007, 2008, 2009, 2010, 2011 Free Software Foundation, Inc.
+//   Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -84,7 +85,7 @@ StartSoundTag::executeActions(MovieClip* m, DisplayList& /* dlist */) const
     if (handler) {
         if (_soundInfo.stopPlayback) {
             //log_debug("Execute StartSoundTag with 'stop playback' flag on");
-            handler->stop_sound(m_handler_id);
+            handler->stopEventSound(m_handler_id);
         }
         else {
 
