@@ -1,6 +1,7 @@
 // FLVParser.h:  Flash Video file format parser, for Gnash.
 //
-//   Copyright (C) 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
+//   Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -28,7 +29,6 @@
 #include "SimpleBuffer.h" 
 
 #include <set>
-#include <vector>
 #include <memory>
 #include <map>
 
