@@ -1,6 +1,7 @@
 // MediaParserFfmpeg.cpp: FFMPEG media parsers, for Gnash
 //
-//   Copyright (C) 2007, 2008, 2009, 2010, 2011 Free Software Foundation, Inc.
+//   Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -36,17 +37,17 @@ namespace ffmpeg {
 
 namespace { 
 
-	// Used to calculate a decimal value from a ffmpeg fraction
-	inline double as_double(AVRational time)
-	{
-		return time.num / static_cast<double>(time.den);
-	}
+// Used to calculate a decimal value from a ffmpeg fraction
+inline double as_double(AVRational time) {
+    return time.num / static_cast<double>(time.den);
+}
 
 } // anonymous namespace
 
 
 int
-MediaParserFfmpeg::readPacketWrapper(void* opaque, boost::uint8_t* buf, int buf_size)
+MediaParserFfmpeg::readPacketWrapper(void* opaque, boost::uint8_t* buf,
+        int buf_size)
 {
 	MediaParserFfmpeg* p = static_cast<MediaParserFfmpeg*>(opaque);
 	return p->readPacket(buf, buf_size);
@@ -62,7 +63,7 @@ MediaParserFfmpeg::seekMediaWrapper(void *opaque, boost::int64_t offset, int whe
 AVInputFormat*
 MediaParserFfmpeg::probeStream()
 {
-    const size_t probeSize = 2048;
+    const size_t probeSize = 4096;
     const size_t bufSize = probeSize + FF_INPUT_BUFFER_PADDING_SIZE;
 
 	boost::scoped_array<boost::uint8_t> buffer(new boost::uint8_t[bufSize]);
@@ -75,8 +76,7 @@ MediaParserFfmpeg::probeStream()
 
 	_stream->seek(0);
 
-	if (actuallyRead < 1)
-	{
+	if (actuallyRead < 1) {
  		throw IOException(_("MediaParserFfmpeg could not read probe data "
                     "from input"));
 	}
@@ -94,44 +94,52 @@ MediaParserFfmpeg::probeStream()
 bool
 MediaParserFfmpeg::seek(boost::uint32_t& pos)
 {
-	LOG_ONCE(log_unimpl("MediaParserFfmpeg::seek()"));
-	return false;
+    // lock the stream while reading from it, so actionscript
+    // won't mess with the parser on seek  or on getBytesLoaded
+    boost::mutex::scoped_lock streamLock(_streamMutex);
 
-	log_debug("MediaParserFfmpeg::seek(%d) TESTING", pos);
+    // NOTE: seeking when timestamps are unknown is a pain
+    // See https://savannah.gnu.org/bugs/index.php?33085
+    // TODO: newer ffmpeg versions seem to have an
+    //  av_seek_frame_generic() function 
+    // which may help us. May be worth taking a look
+    //
+    if ( pos == 0 ) {
+        // Handle 0 by seeking to byte 0
+        // Doing this saves lots of headakes in absence
+        // of correct timestamps (which is the case for mp3)
+        log_debug("Seeking MediaParserFfmpeg input to byte offset zero");
+        if (av_seek_frame(_formatCtx, -1, pos, AVSEEK_FLAG_BYTE) < 0) {
+            log_error(_("%s: seeking failed"), __FUNCTION__);
+            return 0;
+        }
+    }
+    else {
+        // This is most likely wrong
+	    log_debug("MediaParserFfmpeg::seek(%d) TESTING", pos);
+        long newpos = static_cast<long>(pos / AV_TIME_BASE);
+        if (av_seek_frame(_formatCtx, -1, newpos, 0) < 0) {
+            log_error(_("%s: seeking failed"), __FUNCTION__);
+            return 0;
+        }
+    }
 
-	AVStream* videostream = _formatCtx->streams[_videoStreamIndex];
-    	double timebase = static_cast<double>(videostream->time_base.num / videostream->time_base.den);
-	long newpos = static_cast<long>(pos / timebase);
-		
-	if (av_seek_frame(_formatCtx, _videoStreamIndex, newpos, 0) < 0)
-	{
-		log_error(_("%s: seeking failed"), __FUNCTION__);
-		return 0;
-	}
+    // We'll restart parsing
+    _parsingComplete = false;
 
-	AVPacket Packet;
-	av_init_packet(&Packet);
-	double newtime = 0;
-	while (newtime == 0)
-	{
-		if (av_read_frame(_formatCtx, &Packet) < 0) 
-		{
-			log_error("Error in av_read_frame (while seeking)");
-			av_seek_frame(_formatCtx, -1, 0, AVSEEK_FLAG_BACKWARD);
-			//av_free_packet( &Packet );
-			return 0; // ??
-		}
-
-		newtime = timebase * static_cast<double>(_formatCtx->streams[_videoStreamIndex]->cur_dts);
-	}
-
-	//av_free_packet( &Packet );
-	av_seek_frame(_formatCtx, _videoStreamIndex, newpos, 0);
-
-	newtime = static_cast<boost::int32_t>(newtime / 1000.0);
-	log_debug("Seek requested to time %d triggered seek to key frame at "
-            "time %d", pos, newtime);
-	pos = newtime;
+    // Finally, clear the buffers.
+    // The call will also wake the parse up if it was sleeping.
+    // WARNING: a race condition might be pending here:
+    // If we handled to do all the seek work in the *small*
+    // time that the parser runs w/out mutex locked (ie:
+    // after it unlocked the stream mutex and before it locked
+    // the queue mutex), it will still push an old encoded frame
+    // to the queue; if the pushed frame alone makes it block
+    // again (bufferFull) we'll have a problem.
+    // Note though, that a single frame can't reach a bufferFull
+    // condition, as it takes at least two for anything != 0.
+    //
+    clearBuffers();
 
     return true;
 }
@@ -200,8 +208,8 @@ MediaParserFfmpeg::parseAudioFrame(AVPacket& packet)
         //   mdb:93, lastbuf:0 skiping granule 0
         // When playing: http://downloads.bbc.co.uk/news/nol/shared/spl/hi/audio_slideshow/kenadamptw/slideshow_629.swf
         //
-        LOG_ONCE(log_error("FIXME: FFmpeg packet decompression "
-                    "timestamp has no value, taking as zero"));
+        LOG_ONCE(log_error(_("FIXME: FFmpeg packet decompression "
+                             "timestamp has no value, taking as zero")));
         dts = 0;
     }
 	boost::uint64_t timestamp = static_cast<boost::uint64_t>(dts * as_double(_audioStream->time_base) * 1000.0); 
@@ -302,14 +310,13 @@ MediaParserFfmpeg::parseNextFrame()
 bool
 MediaParserFfmpeg::parseNextChunk()
 {
-	if ( ! parseNextFrame() ) return false;
+	if (!parseNextFrame()) return false;
 	return true;
 }
 
 boost::uint64_t
 MediaParserFfmpeg::getBytesLoaded() const
 {
-	//log_unimpl("%s", __PRETTY_FUNCTION__);
 	return _lastParsedPosition;
 }
 
@@ -340,33 +347,25 @@ MediaParserFfmpeg::initializeParser()
     _byteIOCxt.buffer = NULL;
     
     _inputFmt = probeStream();
+
 #ifdef GNASH_ALLOW_VCODEC_ENV	
-    if ( ! _inputFmt ) {
-	char* defcodec = getenv("GNASH_DEFAULT_VCODEC");
-	if (defcodec && strlen(defcodec))
-	    _inputFmt = av_find_input_format(defcodec);	
-	
+    if (!_inputFmt) {
+        char* defcodec = getenv("GNASH_DEFAULT_VCODEC");
+        if (defcodec && strlen(defcodec)) {
+            _inputFmt = av_find_input_format(defcodec);	
+        }
     }
 #endif	
-    if ( ! _inputFmt ) {
-	throw MediaException("MediaParserFfmpeg couldn't figure out input "
-			     "format");
+    if (! _inputFmt) {
+        throw MediaException("MediaParserFfmpeg couldn't figure out input "
+                     "format");
     }
     
-// av_alloc_format_context was deprecated on
-// 2009-02-08 (r17047) in favor of avformat_alloc_context() 
-#if !defined (LIBAVCODEC_VERSION_MAJOR) || LIBAVCODEC_VERSION_MAJOR < 52
-    _formatCtx = av_alloc_format_context();
-#else
-    _formatCtx = avformat_alloc_context();
-#endif
-
-    assert(_formatCtx);
-    
     // Setup the filereader/seeker mechanism.
     // 7th argument (NULL) is the writer function,
     // which isn't needed.
-    _byteIOBuffer.reset( new unsigned char[byteIOBufferSize] );
+    _byteIOBuffer.reset(new unsigned char[byteIOBufferSize]);
+
     init_put_byte(&_byteIOCxt,
 		  _byteIOBuffer.get(), // buffer
 		  byteIOBufferSize, // buffer size
@@ -378,64 +377,88 @@ MediaParserFfmpeg::initializeParser()
 		  );
     
     _byteIOCxt.is_streamed = 1;
-    
-    // Open the stream. the 4th argument is the filename, which we ignore.
-    if(av_open_input_stream(&_formatCtx, &_byteIOCxt, "", _inputFmt, NULL) < 0)
+
+#if !defined(LIBAVCODEC_VERSION_MAJOR) || LIBAVCODEC_VERSION_MAJOR < 52
+    // Needed for Lenny.
+    _formatCtx = av_alloc_format_context();
+#else
+    _formatCtx = avformat_alloc_context();
+#endif
+
+    assert(_formatCtx);
+
+    // Otherwise av_open_input_stream will reallocate the context.
+    AVFormatParameters ap;
+    std::memset(&ap, 0, sizeof ap);
+    ap.prealloced_context = 1;
+
+    if (av_open_input_stream(&_formatCtx, &_byteIOCxt, "", _inputFmt, &ap) < 0)
     {
         throw IOException("MediaParserFfmpeg couldn't open input stream");
     }
-    
+
+#if defined(LIBAVCODEC_VERSION_MAJOR) && LIBAVCODEC_VERSION_MAJOR >= 52
+    // Note: in at least some versions of ffmpeg, av_open_input_stream does
+    // not parse metadata; not sure why.
+    AVMetadata* md = _formatCtx->metadata;
+    if (md) {
+        AVMetadataTag* tag = av_metadata_get(md, "album", 0,
+                AV_METADATA_MATCH_CASE);
+        if (tag && tag->value) {
+            setId3Info(&Id3Info::album, std::string(tag->value),
+                    _id3Object);
+        }
+    }
+#endif
+
     log_debug("Parsing FFMPEG media file: format:%s; nstreams:%d",
         _inputFmt->name, _formatCtx->nb_streams);
     
-    if ( _formatCtx->title[0] )
-        log_debug(_("  Title:'%s'"), _formatCtx->title);
-    if ( _formatCtx->author[0] )
-        log_debug(_("  Author:'%s'"), _formatCtx->author);
-    if ( _formatCtx->copyright[0] )
-        log_debug(_("  Copyright:'%s'"), _formatCtx->copyright);
-    if ( _formatCtx->comment[0] )
-        log_debug(_("  Comment:'%s'"), _formatCtx->comment);
-    if ( _formatCtx->album[0] )
-        log_debug(_("  Album:'%s'"), _formatCtx->album);
-    
     // Find first audio and video stream
-    for (unsigned int i = 0; i < static_cast<unsigned int>(_formatCtx->nb_streams); i++)
-	{
+    for (size_t i = 0; i < static_cast<size_t>(_formatCtx->nb_streams); ++i) {
+
 	    AVStream* stream = _formatCtx->streams[i];
-	    if ( ! stream ) {
-		log_debug("Stream %d of FFMPEG media file is null ?", i);
-		continue;
+	    if (! stream) {
+            log_debug("Stream %d of FFMPEG media file is null ?", i);
+            continue;
 	    }
 	    
 	    AVCodecContext* enc = stream->codec; 
-	    if ( ! enc ) {
-		log_debug("Stream %d of FFMPEG media file has no codec info", i);
-		continue;
+	    if (!enc) {
+            log_debug("Stream %d of FFMPEG media file has no codec info", i);
+            continue;
 	    }
 	    
 	    switch (enc->codec_type) {
-	    case CODEC_TYPE_AUDIO:
-		if (_audioStreamIndex < 0) {
-		    _audioStreamIndex = i;
-		    _audioStream = _formatCtx->streams[i];
-		    log_debug(_("  Using stream %d for audio: codec id %d"),
-			      i, _audioStream->codec->codec_id);
-		    // codec_name will only be filled by avcodec_find_decoder (later);
-		}
-		break;
+#if LIBAVCODEC_VERSION_MAJOR >= 53
+            case AVMEDIA_TYPE_AUDIO:
+#else
+            case CODEC_TYPE_AUDIO:
+#endif
+                if (_audioStreamIndex < 0) {
+                    _audioStreamIndex = i;
+                    _audioStream = _formatCtx->streams[i];
+                    // codec_name will only be filled by avcodec_find_decoder
+                    // (later);
+                    log_debug(_("  Using stream %d for audio: codec id %d"),
+                          i, _audioStream->codec->codec_id);
+                }
+                break;
 		
-	    case CODEC_TYPE_VIDEO:
-		if (_videoStreamIndex < 0) {
-		    _videoStreamIndex = i;
-		    _videoStream = _formatCtx->streams[i];
-		    log_debug(_("  Using stream %d for video: codec id %d"),
-			      i, _videoStream->codec->codec_id);
-		    // codec_name will only be filled by avcodec_find_decoder (later);
-		}
-		break;
-	    default:
-		break;
+#if LIBAVCODEC_VERSION_MAJOR >= 53
+            case AVMEDIA_TYPE_VIDEO:
+#else
+            case CODEC_TYPE_VIDEO:
+#endif
+                if (_videoStreamIndex < 0) {
+                    _videoStreamIndex = i;
+                    _videoStream = _formatCtx->streams[i];
+                    log_debug(_("  Using stream %d for video: codec id %d"),
+                          i, _videoStream->codec->codec_id);
+                }
+                break;
+            default:
+                break;
 	    }
 	}
     
@@ -444,14 +467,15 @@ MediaParserFfmpeg::initializeParser()
         const int codec = static_cast<int>(_videoStream->codec->codec_id); 
         boost::uint16_t width = _videoStream->codec->width;
         boost::uint16_t height = _videoStream->codec->height;
-        boost::uint16_t frameRate = static_cast<boost::uint16_t>(as_double(_videoStream->r_frame_rate));
+        boost::uint16_t frameRate = static_cast<boost::uint16_t>(
+                as_double(_videoStream->r_frame_rate));
 #if !defined(HAVE_LIBAVFORMAT_AVFORMAT_H) && !defined(HAVE_FFMPEG_AVCODEC_H)
         boost::uint64_t duration = _videoStream->codec_info_duration;
 #else
         boost::uint64_t duration = _videoStream->duration;
 #endif
         if (duration == AV_NOPTS_VALUE) {
-            log_error("Duration of video stream unknown");
+            log_error(_("Duration of video stream unknown"));
             duration=0; // TODO: guess!
         } else {
             duration = duration / as_double(_videoStream->time_base); // TODO: check this
@@ -468,7 +492,8 @@ MediaParserFfmpeg::initializeParser()
     }
     
     // Create AudioInfo
-    if ( _audioStream) {
+    if (_audioStream) {
+
         const int codec = static_cast<int>(_audioStream->codec->codec_id); 
         boost::uint16_t sampleRate = _audioStream->codec->sample_rate;
         boost::uint16_t sampleSize = SampleFormatToSampleSize(_audioStream->codec->sample_fmt);
@@ -479,7 +504,7 @@ MediaParserFfmpeg::initializeParser()
         boost::uint64_t duration = _audioStream->duration;
 #endif
         if (duration == AV_NOPTS_VALUE) {
-            log_error("Duration of audio stream unknown to ffmpeg");
+            log_error(_("Duration of audio stream unknown to ffmpeg"));
             duration=0; // TODO: guess!
         } 
         else {
@@ -535,6 +560,12 @@ MediaParserFfmpeg::readPacket(boost::uint8_t* buf, int buf_size)
 
 }
 
+boost::optional<Id3Info>
+MediaParserFfmpeg::getId3Info() const
+{
+    return _id3Object;
+}
+
 // NOTE: as this function is used as a callback from FFMPEG, it should not
 // throw any exceptions, because:
 // a) The behaviour of C++ exceptions passed into C code is undefined.
