@@ -1,6 +1,7 @@
 // MediaHandlerGst.h: GST media handler, for Gnash
 // 
-//   Copyright (C) 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
+//   Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc.
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -19,9 +20,9 @@
 #ifndef GNASH_MEDIAHANDLERGST_H
 #define GNASH_MEDIAHANDLERGST_H
 
-#include "dsodefs.h" // DSOEXPORT
-#include "MediaHandler.h" // for inheritance
+#include "MediaHandler.h"
 
+#include <vector>
 #include <memory>
 
 namespace gnash {
@@ -38,11 +39,12 @@ namespace gst {
 /// It uses gstreamer: http://gstreamer.freedesktop.org/
 ///
 /// Starting point is MediaHandlerGst.
-/// 
-class DSOEXPORT MediaHandlerGst : public MediaHandler
+class MediaHandlerGst : public MediaHandler
 {
 public:
 
+    virtual std::string description() const;
+
 	virtual std::auto_ptr<MediaParser>
         createMediaParser(std::auto_ptr<IOChannel> stream);
 
@@ -64,6 +66,7 @@ public:
 };
 
 
+
 } // gnash.media.gst namespace
 } // gnash.media namespace 
 } // namespace gnash
