@@ -1,7 +1,7 @@
 // plugin.cpp:  Windows "win32" flash player Mozilla plugin, for Gnash.
 // 
-//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010,
-//   2011 Free Software Foundation, Inc
+//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -77,6 +77,9 @@ static int module_initialized = FALSE;
 static PRLock* playerLock = NULL;
 static int instances = 0;
 
+#ifdef NPAPI_CONST
+const
+#endif
 char* NPP_GetMIMEDescription(void);
 static void playerThread(void *arg);
 static LRESULT CALLBACK PluginWinProc(HWND, UINT, WPARAM, LPARAM);
@@ -119,6 +122,9 @@ NS_PluginShutdown(void)
 }
 
 /// \brief Return the MIME Type description for this plugin.
+#ifdef NPAPI_CONST
+const
+#endif
 char*
 NPP_GetMIMEDescription(void)
 {
