@@ -1,5 +1,6 @@
 // 
-//   Copyright (C) 2007, 2008, 2009 Free Software Foundation, Inc.
+//   Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc.
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -19,11 +20,10 @@
 #define GNASH_DUMMYCHARACTER_H
 
 #include "InteractiveObject.h" // for inheritance
-#include "rect.h" // for composition
+#include "SWFRect.h" // for composition
 #include "Movie.h" // for createMovie
 #include "snappingrange.h" // for InvalidatedRanges typedef (don't like it)
 
-#include <string>
 #include <memory> // for auto_ptr
 
 // Forward declarations
@@ -45,18 +45,20 @@ class DummyCharacter : public InteractiveObject
 
 public:
 
-	DummyCharacter(DisplayObject* parent)
+	DummyCharacter(as_object* object, DisplayObject* parent)
 		:
-		InteractiveObject(parent, parent ? 0 : -1)
+		InteractiveObject(object, parent)
 	{
 	}
 
-    virtual void display(Renderer& /*renderer*/) {}
+    virtual void display(Renderer& /*renderer*/, const Transform&) {}
 
-    virtual rect getBounds() const { return rect(); }
+    virtual SWFRect getBounds() const { return SWFRect(); }
 
     virtual bool mouseEnabled() const { return true; }
 
+    virtual void mouseEvent(const event_id&) {}
+
     InteractiveObject* topmostMouseEntity(boost::int32_t, boost::int32_t)
     {
         return 0;
