@@ -1,5 +1,6 @@
 /* 
- *   Copyright (C) 2007, 2008, 2009, 2010 Free Software Foundation, Inc.
+ *   Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012
+ *   Free Software Foundation, Inc.
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -53,15 +54,13 @@ main(int /*argc*/, char** /*argv*/)
 	assert(root);
 
 	// for variables lookup (consistency checking)
-	string_table& st = getStringTable(*getObject(root));
+	VM& vm = getVM(*getObject(root));
 
 	rgba white(255, 255, 255, 255); // background color
 	rgba blue(0, 0, 255, 255);      // blue circles fill color
 	rgba green(0, 255, 0, 255);     // green circles fill color
 	rgba red(255, 0, 0, 255);       // red circles fill color
 
-	int cs = 20;             // circles size
-
 	point out(350, 100);  // out of any drawing
 
 	point rc1(50, 50);    // first red circle
@@ -113,7 +112,7 @@ main(int /*argc*/, char** /*argv*/)
 		{
 			check(!"loadTarget was never loaded");
 			cerr << "Root display list is: " << endl;
-			root->getDisplayList().dump();
+            std::cerr << root->getDisplayList();
 			exit(EXIT_FAILURE);
 		}
 
@@ -163,19 +162,28 @@ main(int /*argc*/, char** /*argv*/)
 	tester.movePointerTo(bc3.x, bc3.y);
 	tester.click(); 
 
-	// 11. Click ANYWHERE OUT of the THIRD BLUE circle (on another circle makes a better test)
+	// 11. Click on the SECOND GREEN circle.
+    // (Checks that the textfield has moved)
+	tester.movePointerTo(gc2.x, gc2.y);
+
+    // Make sure the position is updated!
+    tester.advance();
+
+	tester.click();
+
+	// 12. Click ANYWHERE OUT of the THIRD BLUE circle (on another circle makes a better test)
 	tester.movePointerTo(rc1.x, rc1.y);
 	tester.click();
 
 	// Consistency check !!
 	as_value eot;
 	// It's an swf6, so lowercase 'ENDOFTEST'
-	bool endOfTestFound = getObject(root)->get_member(st.find("endoftest"), &eot);
+	bool endOfTestFound = getObject(root)->get_member(getURI(vm, "endoftest"), &eot);
 	check(endOfTestFound);
 	if ( endOfTestFound )
 	{
-		cerr << eot.toDebugString() << endl;
-		check_equals(eot.to_bool(), true);
+		cerr << eot << endl;
+		check_equals(eot.to_bool(8), true);
 	}
 	else
 	{
