@@ -1,7 +1,7 @@
 // processor.cpp:  Flash movie processor (gprocessor command), for Gnash.
 // 
-//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010 Free Software
-//   Foundation, Inc
+//   Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
+//   Free Software Foundation, Inc
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -17,28 +17,27 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-
 #ifdef HAVE_CONFIG_H
 #include "gnashconfig.h"
 #endif
 
-#include "NullSoundHandler.h"
-
 #include <ios>
 #include <iostream>
 #include <cstdio>
 #include <cstdlib>
 #include <ctime>
+#include <typeinfo>
+#include <boost/any.hpp>
 
 #ifdef ENABLE_NLS
 # include <clocale>
 #endif
 
+#include "NullSoundHandler.h"
 #include "MovieFactory.h"
 #include "swf/TagLoadersTable.h"
 #include "swf/DefaultTagLoaders.h"
 #include "ClockTime.h"
-#include "gnash.h"
 #include "movie_definition.h"
 #include "MovieClip.h"
 #include "movie_root.h"
@@ -46,16 +45,20 @@
 #include "rc.h"
 #include "URL.h"
 #include "GnashException.h"
-#include "debugger.h"
 #include "VM.h"
 #include "noseek_fd_adapter.h"
 #include "ManualClock.h"
 #include "StringPredicates.h"
-#include "smart_ptr.h"
 #include "IOChannel.h" // for proper dtor call
 #include "GnashSleep.h" // for usleep comptibility.
 #include "StreamProvider.h"
 #include "RunResources.h"
+#include "HostInterface.h"
+
+#ifdef RENDERER_AGG
+#include "Renderer.h"
+#include "Renderer_agg.h"
+#endif
 
 extern "C"{
 #ifdef HAVE_GETOPT_H
@@ -106,13 +109,10 @@ static void usage (const char *);
 namespace {
 gnash::LogFile& dbglogfile = gnash::LogFile::getDefaultInstance();
 gnash::RcInitFile& rcfile = gnash::RcInitFile::getDefaultInstance();
-#ifdef USE_DEBUGGER
-gnash::Debugger& debugger = gnash::Debugger::getDefaultInstance();
-#endif
 }
 
-static bool play_movie(
-        const std::string& filename, const RunResources& runResources);
+static bool play_movie(const std::string& filename,
+        const RunResources& runResources);
 
 static bool s_stop_on_errors = true;
 
@@ -141,7 +141,7 @@ secondsSinceLastAdvance()
 //
 static int quitrequested = false;
 
-class FsCommandExecutor: public movie_root::AbstractFsCallback {
+class FsCommandExecutor: public FsCallback {
 public:
 	void notify(const std::string& command, const std::string& args)
 	{
@@ -153,61 +153,60 @@ public:
 	}
 };
 
-class EventCallback: public movie_root::AbstractIfaceCallback
+class EventCallback: public HostInterface
 {
 public:
-	std::string call(const std::string& event, const std::string& arg)
+    boost::any call(const HostInterface::Message& e)
 	{
-	    log_debug(_("eventCallback: %s %s"), event, arg);
+        if (e.type() != typeid(HostMessage)) return boost::blank();
+
+        const HostMessage& ev = boost::get<HostMessage>(e);
+        const HostMessage::KnownEvent event = ev.event();
+
+        log_debug(_("eventCallback: %s %s"), event);
 
 	    static bool mouseShown = true;
+	    static std::string clipboard;
 
-	    // These should return "true" if the mouse was visible before
-	    // the call.
-	    if ( event == "Mouse.hide" ) {
-            bool state = mouseShown;
-            mouseShown = false;
-            return state ? "true" : "false";
-	    }
+        switch (event) {
+            case HostMessage::QUERY:
+                return true;
+            case HostMessage::SET_CLIPBOARD:
+                clipboard = boost::any_cast<std::string>(ev.arg());
+                return boost::blank();
 
-	    if ( event == "Mouse.show" ) {
-            bool state = mouseShown;
-            mouseShown = true;
-            return state ? "true" : "false" ;
-	    }
-	    
-	    // Some fake values for consistent test results.
-	    
-	    if ( event == "System.capabilities.screenResolutionX" ) {
-            return "800";
-	    }
+            case HostMessage::SHOW_MOUSE:
+            {
+                bool state = mouseShown;
+                mouseShown = boost::any_cast<bool>(ev.arg());
+                return state;
+            }
 
-	    if ( event == "System.capabilities.screenResolutionY" ) {
-            return "640";
-	    } 
+            // Some fake values for consistent test results.
+            case HostMessage::SCREEN_RESOLUTION:
+                return std::make_pair(800, 640);
 
-	    if ( event == "System.capabilities.screenDPI" ) {
-            return "72";
-	    }        
+	        case HostMessage::SCREEN_DPI:
+                return 72.0;
 
-	    if ( event == "System.capabilities.screenColor" ) {
-            return "Color";
-	    } 
+	        case HostMessage::SCREEN_COLOR:
+                return std::string("Color");
 
-	    if ( event == "System.capabilities.playerType" ) {
-            return "StandAlone";
-	    } 
+	        case HostMessage::PLAYER_TYPE:
+                return std::string("StandAlone");
 
-	    return "";
+	        case HostMessage::PIXEL_ASPECT_RATIO:
+                return 0.9978;
 
+            default:
+                log_debug(_("gprocessor does not handle %1% message"), e);
+                break;
+        }
+
+	    return boost::blank();
 	}
 
-    bool yesNo(const std::string& /*query*/)
-    {
-        return true;
-    }
-
-    void exit() {
+    virtual void exit() {
         std::exit(EXIT_SUCCESS);
     }
 };
@@ -220,9 +219,6 @@ main(int argc, char *argv[])
 {
     std::ios::sync_with_stdio(false);
 
-    /// Initialize gnash core library
-    gnashInit();
-
     // Enable native language support, i.e. internationalization
 #ifdef ENABLE_NLS
     std::setlocale (LC_ALL, "");
@@ -235,12 +231,12 @@ main(int argc, char *argv[])
     for (c = 0; c < argc; c++) {
       if (strcmp("--help", argv[c]) == 0) {
         usage(argv[0]);
-        exit(EXIT_SUCCESS);
+        return EXIT_SUCCESS;
       }
       if (strcmp("--version", argv[c]) == 0) {
         printf (_("Gnash gprocessor version: %s, Gnash version: %s\n"),
 		   GPROC_VERSION, VERSION);
-        exit(EXIT_SUCCESS);
+        return EXIT_SUCCESS;
       }
     }
  
@@ -274,19 +270,11 @@ main(int argc, char *argv[])
 	  case 'h':
 	      usage (argv[0]);
               dbglogfile.removeLog();
-	      exit(EXIT_SUCCESS);
+	      return EXIT_SUCCESS;
 	  case 'v':
 	      dbglogfile.setVerbosity();
 	      log_debug (_("Verbose output turned on"));
 	      break;
-          case 'g':
-#ifdef USE_DEBUGGER
-              debugger.enabled(true);
-              debugger.console();
-              log_debug (_("Setting debugger ON"));
-#else
-              log_error (_("The debugger has been disabled at configuration time"));
-#endif
 	  case 'n':
 	      dbglogfile.setNetwork(true); 
 	      break;
@@ -317,11 +305,11 @@ main(int argc, char *argv[])
 	      break;
 	  case ':':
               fprintf(stderr, "Missing argument for switch ``%c''\n", optopt); 
-	      exit(EXIT_FAILURE);
+	      return EXIT_FAILURE;
 	  case '?':
 	  default:
               fprintf(stderr, "Unknown switch ``%c''\n", optopt); 
-	      exit(EXIT_FAILURE);
+	      return EXIT_FAILURE;
 	}
     }
     
@@ -337,48 +325,52 @@ main(int argc, char *argv[])
 	    std::cerr << "no input files" << std::endl;
 	    usage(argv[0]);
         dbglogfile.removeLog();
-	    exit(EXIT_FAILURE);
+	    return EXIT_FAILURE;
     }
 
-    if (infiles.size() > 1)
-    {
-        // We're not ready for multiple runs yet.
-        std::cerr << "Multiple input files not supported." << std::endl;
-        usage(argv[0]);
-        dbglogfile.removeLog();
-        exit(EXIT_FAILURE);
-    }
-
-
     boost::shared_ptr<gnash::media::MediaHandler> mediaHandler;
     boost::shared_ptr<sound::sound_handler> soundHandler;
 
-    mediaHandler.reset(media::MediaFactory::instance().get(""));
+    std::string mh = rcfile.getMediaHandler();
+    mediaHandler.reset(media::MediaFactory::instance().get(mh));
     soundHandler.reset(new sound::NullSoundHandler(mediaHandler.get()));
 
-    boost::shared_ptr<StreamProvider> sp(new StreamProvider);
-
-
     boost::shared_ptr<SWF::TagLoadersTable> loaders(new SWF::TagLoadersTable());
     addDefaultLoaders(*loaders);
 
+#ifdef RENDERER_AGG
+    boost::shared_ptr<Renderer_agg_base> r(create_Renderer_agg("RGBA32"));
+
+    // Yes, this leaks. On some systems (e.g. Debian Lenny) the data is
+    // evidently accessed after main() returns. Rather than bothering to
+    // work out why, we let this byte leak, as it's returned to the system on
+    // exit anyway.
+    unsigned char* buf = new unsigned char[8];
+    r->init_buffer(buf, 1, 1, 1, 1);
+#endif
+
     // Play through all the movies.
     for (std::vector<std::string>::const_iterator i = infiles.begin(), 
             e = infiles.end(); i != e; ++i)
     {
 
-        RunResources runResources(*i);
+        RunResources runResources;
         runResources.setSoundHandler(soundHandler);
         runResources.setMediaHandler(mediaHandler);
-        runResources.setStreamProvider(sp);
         runResources.setTagLoaders(loaders);
+        boost::shared_ptr<StreamProvider> sp(new StreamProvider(*i, *i));
+        runResources.setStreamProvider(sp);
+
+#ifdef RENDERER_AGG
+        runResources.setRenderer(r);
+#endif
 
 	    bool success = play_movie(*i, runResources);
 	    if (!success) {
 	        if (s_stop_on_errors) {
 		    // Fail.
                 std::cerr << "error playing through movie " << *i << std::endl;
-		        std::exit(EXIT_FAILURE);
+		        return EXIT_FAILURE;
 	        }
         }
 	
@@ -387,6 +379,45 @@ main(int argc, char *argv[])
     return 0;
 }
 
+struct SamplesFetcher {
+	sound::sound_handler& _sh;
+	unsigned int _samplesFetched;
+	
+	SamplesFetcher(sound::sound_handler& sh)
+        : _sh(sh), _samplesFetched(0)
+    {}
+
+    // Fetch as many samples as needed for `ms' milliseconds of playback
+    void fetch(unsigned int ms)
+    {
+        // We need to fetch as many samples
+        // as needed for a theoretical 44100hz loop.
+        // That is 44100 samples each second.
+        // 44100/1000 = x/ms
+        //  x = (44100*ms) / 1000
+        unsigned int nSamples = (441*ms) / 10;
+
+        // We double because sound_handler interface takes
+        // "mono" samples... (eh.. would be wise to change)
+        unsigned int toFetch = nSamples*2;
+
+        // Now substract what we fetched already
+        toFetch -= _samplesFetched;
+
+        // And update _samplesFetched..
+        _samplesFetched += toFetch;
+
+        //log_debug("SamplesFetcher::fetch(%d) fetching %d samples", ms, toFetch);
+
+        boost::int16_t samples[1024];
+        while (toFetch) {
+            unsigned int n = std::min(toFetch, 1024u);
+            _sh.fetchSamples(samples, n);
+            toFetch -= n;
+        }
+    }
+};
+
 // Load the named movie, make an instance, and play it, virtually.
 // I.e. run through and render all the frames, even though we are not
 // actually doing any output (our output handlers are disabled).
@@ -394,12 +425,17 @@ main(int argc, char *argv[])
 bool
 play_movie(const std::string& filename, const RunResources& runResources)
 {
+
+    sound::sound_handler* sh = runResources.soundHandler();
+    sh->reset();
+    SamplesFetcher sFetcher(*sh);
+
     boost::intrusive_ptr<gnash::movie_definition> md;
 
     quitrequested = false;
 
     URL url(filename);
-
+    
     try
     {
       if (filename == "-")
@@ -435,7 +471,7 @@ play_movie(const std::string& filename, const RunResources& runResources)
         std::cerr << "error: can't play movie: "<< filename << std::endl;
 	    return false;
     }
-
+    
     float fps = md->get_frame_rate();
     long fpsDelay = long(1000000/fps);
     long clockAdvance = fpsDelay/1000;
@@ -447,125 +483,124 @@ play_movie(const std::string& filename, const RunResources& runResources)
 
     // Use a clock advanced at every iteration to match exact FPS speed.
     ManualClock cl;
-    gnash::movie_root m(*md, cl, runResources);
-    
-    // Register processor to receive ActionScript events (Mouse, Stage
-    // System etc).
-    m.registerEventCallback(&eventCallback);
-    m.registerFSCommandCallback(&execFsCommand);
 
-    md->completeLoad();
 
-    MovieClip::MovieVariables v;
-    m.init(md.get(), v, v);
-
-    log_debug("iteration, timer: %lu, localDelay: %ld\n",
-            cl.elapsed(), localDelay);
-    gnashSleep(localDelay);
-    
-    resetLastAdvanceTimer();
-    int	kick_count = 0;
-    int stop_count=0;
-    size_t loop_back_count=0;
-    size_t latest_frame=0;
-    size_t end_hitcount=0;
-    size_t nadvances=0;
-    // Run through the movie.
-    while (!quitrequested) {
-        // @@ do we also have to run through all sprite frames
-        // as well?
-        //
-        // @@ also, ActionScript can rescale things
-        // dynamically -- we can't really do much about that I
-        // guess?
-        //
-        // @@ Maybe we should allow the user to specify some
-        // safety margin on scaled shapes.
+    // Scope to ensure that movie_root is destroyed before the library
+    // is cleared; otherwise movie_root's MovieLoader can continue to
+    // add movie_definitions to MovieLibrary, which then keeps them
+    // and their parsing thread alive until static destruction. The parser
+    // can then continue to access destroyed resources.
+    {
+        gnash::movie_root m(cl, runResources);
         
-        size_t	last_frame = m.get_current_frame();
-        //printf("advancing clock by %lu\n", clockAdvance);
-        cl.advance(clockAdvance);
-        m.advance();
+        // Register processor to receive ActionScript events (Mouse, Stage
+        // System etc).
+        m.registerEventCallback(&eventCallback);
+        m.registerFSCommandCallback(&execFsCommand);
 
-        if ( quitrequested ) 
-        {
-            quitrequested = false;
-            break;
-        }
+        md->completeLoad();
 
-        m.display(); // FIXME: for which reason are we calling display here ??
-        ++nadvances;
-        if ( limit_advances && nadvances >= limit_advances)
-        {
-            log_debug("exiting after %d advances", nadvances);
-            break;
-        }
+        MovieClip::MovieVariables v;
+        m.init(md.get(), v);
 
-        size_t curr_frame = m.get_current_frame();
-        
-        // We reached the end, done !
-        if (curr_frame >= md->get_frame_count() - 1 )
-        {
-            if ( allowed_end_hits && ++end_hitcount >= allowed_end_hits )
-            {
-                log_debug("exiting after %d" 
-                       " times last frame was reached", end_hitcount);
-                    break;
-            }
-        }
-
-        // We didn't advance 
-        if (curr_frame == last_frame)
-        {
-            // Max stop counts reached, kick it
-            if ( secondsSinceLastAdvance() > waitforadvance )
-            {
-                stop_count=0;
-
-                // Kick the movie.
-                if ( last_frame + 1 > md->get_frame_count() -1 )
-                {
-                    fprintf(stderr, "Exiting after %g seconds in STOP mode at last frame\n", waitforadvance);
-                    break;
-                }
-                fprintf(stderr, "Kicking movie after %g seconds in STOP mode, kick ct = %d\n", waitforadvance, kick_count);
-                fflush(stderr);
-                m.goto_frame(last_frame + 1);
-                m.set_play_state(gnash::MovieClip::PLAYSTATE_PLAY);
-                kick_count++;
-
-                if (kick_count > 10) {
-                    printf("movie is stalled; giving up on playing it through.\n");
-                    break;
-                }
-
-                    resetLastAdvanceTimer(); // It's like we advanced
-            }
-        }
-        
-        // We looped back.  Skip ahead...
-        else if (m.get_current_frame() < last_frame)
-        {
-            if ( last_frame > latest_frame ) latest_frame = last_frame;
-            if ( ++loop_back_count > allowloopbacks )
-            {
-                log_debug("%d loop backs; jumping one-after "
-                        "latest frame (%d)",
-                        loop_back_count, latest_frame+1);
-                m.goto_frame(latest_frame + 1);
-                loop_back_count = 0;
-            }
-        }
-        else
-        {
-            kick_count = 0;
-            stop_count = 0;
-            resetLastAdvanceTimer();
-        }
-
-        log_debug("iteration, timer: %lu, localDelay: %ld\n",
+        log_debug("iteration, timer: %lu, localDelay: %ld",
                 cl.elapsed(), localDelay);
         gnashSleep(localDelay);
+        
+        resetLastAdvanceTimer();
+        int	kick_count = 0;
+        size_t loop_back_count=0;
+        size_t latest_frame=0;
+        size_t end_hitcount=0;
+        size_t nadvances=0;
+        // Run through the movie.
+        while (!quitrequested) {
+            
+            size_t	last_frame = m.getRootMovie().get_current_frame();
+            //printf("advancing clock by %lu\n", clockAdvance);
+            cl.advance(clockAdvance);
+            m.advance();
+            sFetcher.fetch(cl.elapsed());
+
+            if ( quitrequested ) 
+            {
+                quitrequested = false;
+                break;
+            }
+
+            m.display(); // FIXME: for which reason are we calling display here ??
+            ++nadvances;
+            if ( limit_advances && nadvances >= limit_advances)
+            {
+                log_debug("exiting after %d advances", nadvances);
+                break;
+            }
+
+            size_t curr_frame = m.getRootMovie().get_current_frame();
+            
+            // We reached the end, done !
+            if (curr_frame >= md->get_frame_count() - 1 )
+            {
+                if ( allowed_end_hits && ++end_hitcount >= allowed_end_hits )
+                {
+                    log_debug("exiting after %d" 
+                           " times last frame was reached", end_hitcount);
+                        break;
+                }
+            }
+
+            // We didn't advance 
+            if (curr_frame == last_frame)
+            {
+                // Max stop counts reached, kick it
+                if ( secondsSinceLastAdvance() > waitforadvance )
+                {
+
+                    // Kick the movie.
+                    if ( last_frame + 1 > md->get_frame_count() -1 )
+                    {
+                        fprintf(stderr, "Exiting after %g seconds in STOP mode at last frame\n", waitforadvance);
+                        break;
+                    }
+                    fprintf(stderr, "Kicking movie after %g seconds in STOP mode, kick ct = %d\n", waitforadvance, kick_count);
+                    fflush(stderr);
+                    m.getRootMovie().goto_frame(last_frame + 1);
+                    m.getRootMovie().setPlayState(gnash::MovieClip::PLAYSTATE_PLAY);
+                    kick_count++;
+
+                    if (kick_count > 10) {
+                        printf("movie is stalled; giving up on playing it through.\n");
+                        break;
+                    }
+
+                        resetLastAdvanceTimer(); // It's like we advanced
+                }
+            }
+            
+            // We looped back.  Skip ahead...
+            else if (m.getRootMovie().get_current_frame() < last_frame)
+            {
+                if ( last_frame > latest_frame ) latest_frame = last_frame;
+                if ( ++loop_back_count > allowloopbacks )
+                {
+                    log_debug("%d loop backs; jumping one-after "
+                            "latest frame (%d)",
+                            loop_back_count, latest_frame+1);
+                    m.getRootMovie().goto_frame(latest_frame + 1);
+                    loop_back_count = 0;
+                }
+            }
+            else
+            {
+                kick_count = 0;
+                resetLastAdvanceTimer();
+            }
+
+            log_debug("iteration, timer: %lu, localDelay: %ld",
+                    cl.elapsed(), localDelay);
+            gnashSleep(localDelay);
+        }
+
     }
 
     log_debug("-- Playback completed");
@@ -576,22 +611,15 @@ play_movie(const std::string& filename, const RunResources& runResources)
     // destruction when core gnash doesn't need it anymore
     md = 0;
 
-    log_debug("-- Clearning movie_root");
-
-    // clear movie_root (shouldn't have bad consequences on itself)
-    m.clear();
-
-    log_debug("-- Clearning gnash");
+    log_debug("-- Cleaning gnash");
  
     // Clear resources.
     // Forces run of GC, which in turn may invoke
     // destuctors of (say) MovieClip which would try
     // to access the movie_root to unregister self
     //
-    // This means that movie_root must be available
-    // while gnash::clear() runs
-    // 
-    gnash::clear();
+    // This means that movie_root must be available.
+    MovieFactory::clear();
 
     return true;
 }
